==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/bg/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Задайте като модул по подразбиране',
    'Always activated' => 'Винаги активиран',
    'Are you sure? *ALL* module data will be lost!' => 'Сигурни ли сте? *ВСИЧКИ* данни от модула ще бъдат загубени!',
    'Are you sure? *ALL* module related data and files will be lost!' => 'Сигурни ли сте? *ВСИЧКИ* данни и файловете, свързани с модула, ще бъдат загубени!',
    'Close' => 'Затваряне',
    'Could not find requested module!' => 'Заявеният модел не може да бъде намерен!',
    'Deactivated' => 'Деактивиран',
    'Enable module...' => 'Активиране на модул...',
    'Enabled' => 'Активиран',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Тук можете да изберете дали даден модул да се активира автоматично в раздела или потребителският профил. Ако модулът трябва да бъде активиран, изберете "Винаги активиран".',
    'Module path %path% is not writeable!' => 'Пътят на модула %path% не позволява записване!',
    'Not available' => 'Не е наличен',
    'Save' => 'Запази',
    'Spaces' => 'Раздели',
    'Users' => 'Потребители',
    'Deactivation of this module has not been completed yet. Please retry in a few minutes.' => '',
    'Module deactivation in progress. This process may take a moment.' => '',
    'Module uninstall in progress. This process may take a moment.' => '',
    'Space default state' => '',
    'The module is currently being used by {nbContainers} users or spaces. If you change its availability, all content created with the module will be lost. Proceed?' => '',
    'Uninstallation of this module has not been completed yet. It will be removed in a few minutes.' => '',
    'User default state' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/bg/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Задайте като модул по подразбиране',
    'Always activated' => 'Винаги активиран',
    'Could not find requested module!' => 'Заявеният модел не може да бъде намерен!',
    'Deactivated' => 'Деактивиран',
    'Enable module...' => 'Активиране на модул...',
    'Enabled' => 'Активиран',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Тук можете да изберете дали даден модул да се активира автоматично в раздела или потребителският профил. Ако модулът трябва да бъде активиран, изберете "Винаги активиран".',
    'Module path %path% is not writeable!' => 'Пътят на модула %path% не позволява записване!',
    'Not available' => 'Не е наличен',
    'Save' => 'Запази',
    'Spaces' => 'Раздели',
    'Users' => 'Потребители',
    'Deactivation of this module has not been completed yet. Please retry in a few minutes.' => '',
    'Disable Module' => '',
    'Disabling the <strong>{moduleName}</strong> module will permanently delete <strong>all</strong> module-related content.' => '',
    'Module deactivation in progress. This process may take a moment.' => '',
    'Module uninstall in progress. This process may take a moment.' => '',
    'Space default state' => '',
    'The module is currently being used by {nbContainers} users or spaces. If you change its availability, all content created with the module will be lost. Proceed?' => '',
    'Uninstall Module' => '',
    'Uninstallation of this module has not been completed yet. It will be removed in a few minutes.' => '',
    'Uninstalling the <strong>{moduleName}</strong> module will permanently delete <strong>all</strong> module-related content.' => '',
    'User default state' => '',
];
